chatsavvy

package module
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 5 Imported by: 0

README

Chatsavvy

Instructions

go get github.com/davesavic/chatsavvy

Usage

Refer to main.go in the examples directory.

Warning

This is a work in progress and is not yet ready for production use.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Migrate added in v0.0.2

func Migrate(client *mongo.Client, direction string) error

Migrate runs the migrations in the specified direction (up or down). Beware that running migrations in the down direction will delete all data.

Types

type ChatSavvy

type ChatSavvy struct {
	Conversation *repository.Conversation
	Message      *repository.Message
	// contains filtered or unexported fields
}

func New

func New(client *mongo.Client) (*ChatSavvy, error)

func (*ChatSavvy) Close added in v0.0.2

func (cs *ChatSavvy) Close() error

Directories

Path Synopsis
cmd
migrate command

Jump to